using System;
using System.Collections;
using System.Text;
using System.Globalization;


namespace BizTalkBill.BizTalkHelpers
{
    public class Map
    {
        public static string GenerateGUID()
        {
            return Guid.NewGuid().ToString();
        }

        public static string FormatMoney(string sMoney)
        {
			Decimal dResult = 0;

			try
			{
				dResult = Decimal.Parse(sMoney);
				return dResult.ToString("C");
			}
			catch 
			{
				return null;
			}

        }

        public enum DateParserOutput { CultureDefault, All, Day, Month, Year, SQLDate };

        public static string DateParser(string InDate, DateParserOutput enumOutput)
        {
            DateTime dtResult;
            string sResult = "";
            if (DateTime.TryParse(InDate, out dtResult))
            {
                switch (enumOutput)
                {
                    case DateParserOutput.Day:
                        sResult = dtResult.ToString("dd");
                        break;
                    case DateParserOutput.Month:
                        sResult = dtResult.ToString("MM");
                        break;
                    case DateParserOutput.Year:
                        sResult = dtResult.ToString("yyyy");
                        break;
                    case DateParserOutput.SQLDate:
                        sResult = dtResult.ToString("yyyy-MM-dd");
                        break;
                    case DateParserOutput.All:
                    case DateParserOutput.CultureDefault:
                    default:
                        sResult = dtResult.ToString("d");
                        break;
                }

            }

            return sResult;
        }

        public static string DateParser(string InDate, string sFormat, DateParserOutput enumOutput)
        {
            return DateParser(InDate, sFormat, enumOutput, "en-AU");
        }

        public static string DateParser(string InDate, string sFormat, string sOutputPart)
        {
            switch (sOutputPart.ToLower())
            {
                case "year":
                    return DateParser(InDate, sFormat, DateParserOutput.Year, "en-AU");
                case "day":
                    return DateParser(InDate, sFormat, DateParserOutput.Day, "en-AU");
                case "month":
                    return DateParser(InDate, sFormat, DateParserOutput.Month, "en-AU");
                case "sqldate":
                    return DateParser(InDate, sFormat, DateParserOutput.SQLDate, "en-AU");
                default:
                    return DateParser(InDate, sFormat, DateParserOutput.All, "en-AU");
            }
        }

        public static string DateParser(string InDate, string sFormat, DateParserOutput enumOutput, string sCulture)
        {
            IFormatProvider culter = new CultureInfo(sCulture);

            DateTime dtResult;
            string sResult = "";
            if (DateTime.TryParseExact(InDate, sFormat, culter, System.Globalization.DateTimeStyles.AllowWhiteSpaces, out dtResult))
            {
                switch (enumOutput)
                {
                    case DateParserOutput.Day:
                        sResult = dtResult.ToString("dd");
                        break;
                    case DateParserOutput.Month:
                        sResult = dtResult.ToString("MM");
                        break;
                    case DateParserOutput.Year:
                        sResult = dtResult.ToString("yyyy");
                        break;
                    case DateParserOutput.SQLDate:
                        sResult = dtResult.ToString("yyyy-MM-dd");
                        break;
                    default:
                        sResult = dtResult.ToString("dd-MM-yyyy");
                        break;
                }
            }
            return sResult;
        }

    }
}
